/* Copyright IBM Corp. 2010  All Rights Reserved. */
/* 
 * @author Ben
 * Summary: Generic iWidget that displays a visual list from context menu data
 */
dojo.provide("com.ibm.mm.builder.systemwidget.ContentSetList");

dojo.require("com.ibm.pb.iwidget.iWidgetBase");

/**
 * Generic iWidget that renders a visual list that represents data retrieved from the public
 * com.ibm.mashups.builder.model.ContextMenu APIs.
 * 
 * Builds its contents dynamically at view time based on the resourceId and the
 * widget's resourceType.
 *  
 */
dojo.declare("com.ibm.mm.builder.systemwidget.ContentSetList", [com.ibm.pb.iwidget.iWidgetBase], {

	
	/**
	 * String CSS class to apply to the menu root node 
	 */
	listCSSClass: "",
	
	/**
	 * String name of the event to subscribe to upon which this iwidget will initialize itself, perhaps
	 * multiple times.  Allows this widget to reinitialize itself in different contexts, for instance
	 * on the page switched event. 
	 */
	initEvent: "",
	
	/**
	 * Array of DOM nodes or DOM node IDs that this menu will open for onClick 
	 */
	//domNodes: [],
	
	/**
	 * The target node on the page that this widget will attach itself to
	 */
	targetDOMNode: null,
	
	/**
	 * The ID of the context menu that this module gets its data from
	 */
	contextMenuID: "",
	
	/**
	 * The type of the resource that this module uses when getting its data from a context menu
	 */
	resourceType: "",
	
	constructor: function() {
		this._listConnections = [];
	},

	getData: function(resourceId) {
		var mname = "getData", lgr = this.LOGGER;
		lgr.entering(mname, arguments);
		var contextMenu = this.builderFactory.getContextMenuModel();
		var data = contextMenu.getContextMenu(this.contextMenuID, resourceId, 
			this.resourceType, { context:this });
		lgr.exiting(mname, [data]);
		return data;
	},

	onLoad: function() {
		var mname = "onLoad", lgr = this.LOGGER;
		lgr.entering(mname, arguments);
		this.inherited(arguments);
		dojo.mixin(this, this.getItemSetValues(["contextMenuID","resourceType","resourceId","init_resourceId","listCSSClass","targetDOMNode","initEvent"]));
		if(!this.resourceId && this.init_resourceId) {
			this.resourceId = dojo.eval(this.init_resourceId); // JSLINT-IGNORE: <eval is neccessary to turn string into expression or function>
		}
		lgr.trace(mname, "Loaded ${0} with resourceId %{1}", [this, this.resourceId]);
		this.targetDOMNode = dojo.byId(this.targetDOMNode);
		if(!this.targetDOMNode) {
			 this.targetDOMNode = this.iContext.getRootElement();
			 this.listNode = dojo.create("ul", {}, this.targetDOMNode);
		}
		else {
			this.listNode = dojo.query("ul", this.targetDOMNode)[0];
		}
		if(this.listCSSClass) {
			dojo.addClass(this.listNode, this.listCSSClass);
		}
		this.init(this.resourceId);
		
		if(this.initEvent) {
			this.evtSvc.subscribeEvent(this.initEvent, this, "init");
		}
    	var eventService = com.ibm.mashups.services.ServiceManager.getService("eventService");
		eventService.broadcastEvent("com.ibm.mashups.builder.refreshSpaceSelector");
		lgr.exiting(mname, arguments);
	},
	
	init: function(resourceId) {
		this.resourceId = resourceId;
		if(!this.refNode) {
			this.refNode = dojo.query("li.content", this.listNode)[0];
			if(!this.refNode) {
				this.refNode = dojo.create("li", {"class": "content", style: {"display": "none"}}, this.listNode);
			}
		}
		dojo.query("> .content-set-item", this.listNode).forEach(dojo.destroy, dojo);
		this.buildList();
	},
	
	buildList: function() {
		var mname = "buildList", lgr = this.LOGGER;
		lgr.entering(mname, arguments);
		while(this._listConnections.length > 0) {
			dojo.disconnect(this._listConnections.shift());
		}
		var data = this.getData(this.resourceId);
		dojo.forEach(data, function(item){
			var li = dojo.create("li", {
				"class": "content-set-item",
				"id": item.id
			}, this.refNode, "before");
			if(item.markup) {
				li.innerHTML = dojo.string.substitute(item.markup, {title: item.title||"", description: item.description||""});
			}
			else {
				var anc = dojo.create("a", {
					href: "javascript:;"
				}, li);
				anc.appendChild(document.createTextNode(item.title));
			}
			
			if(item.iconClass) {
				dojo.addClass(li, item.iconClass);
			}
			this._listConnections.push(dojo.connect(li, "onclick", li, item.actionCallBackFunction));
		}, this);
		lgr.exiting(mname, arguments);
	},
	onUnload: function() {
		while(this._listConnections.length > 0) {
			dojo.disconnect(this._listConnections.shift());
		}
	}
});
