/* Copyright IBM Corp. 2012  All Rights Reserved.                    */
dojo.provide("com.ibm.mashups.enabler.Deferred");

//<INTERFACE>
/**
 * Base interface for all classes which handle actions asynchronously.
 * An action may involve one or more operations, for example creating or
 * updating a model resource, which in turn may involve one or more HTTP
 * requests. The Deferred interface allows to trigger a callback after
 * the entire action, i.e. all involved HTTP requests, is finished. Thus,
 * the Deferred interface may be used to get the overall result of an action.
 * @ibm-api
 * @ibm-module Base2
 */
dojo.declare("com.ibm.mashups.enabler.Deferred", null, {

    /**
     * Sets the handler of the deferred action. It is called when the entire
     * action has finished.<br>
     * <b>Notes:</b>
     * <ul> 
     * <li>The status of the action is transported only with callbacks,
     * even if the deferred action is invoked synchronously. If you need to check the status, 
     * you must use callback functions.</li> 
     * <li>The callback function is invoked either in verbose, or non-verbose
     * mode, depending on the verbose flag you set.</li>
     * </ul>
     * @param {Object} callback the callback function in either one of the following flavors: 
     * <ul>
     * <li><b>verbose</b> mode: <code>function(Object verboseFinishResult)</code>, where:<br>
     * <code>verboseFinishResult = {</code><br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<code>resource:</code> resource object or id string of the related resource,<br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<code>parameter:</code> the parameter passed into <code>setFinishedCallback</code>,<br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<code>request: {</code><br>
     * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<code>statusCode:</code> HTTP status code,<br>
     * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<code>responseText:</code> server response text<br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<code>}</code><br>
     * <code>}</code>
     * </li>
     * <li><b>non-verbose</b> mode: <code>function(Object resource, int statusCode, Object parameter)</code>, where:
     * <ul>
     * <li><code>resource:</code> resource object or id string of the related resource</li>
     * <li><code>statusCode:</code> HTTP status code</li>
     * <li><code>parameter:</code> the parameter passed into <code>setFinishedCallback</code></li>
     * </ul>
     * </li>
     * </ul>
     * @param {Object} parameter optional parameter to be passed on to the callback function; may be <code>null</code>
     * @param {Boolean} verbose flag to indicate if the callback function is invoked in verbose or non-verbose mode; optional, defaults to false
     * @return {com.ibm.mashups.enabler.Deferred} the deferred object
     */
    setFinishedCallback: function(callback, parameter, verbose){
    },
    
    /**
     * Executes the deferred action and invokes the callback functions set
     * with the deferred object after the action finished.
     * @param {Boolean} sync indicates if the deferred action is executed
     * synchronously or asynchronously. Optional, defaults to true.
     * @return {Object} resource if called asynchronously, the return value is
     * <code>undefined</code>, otherwise a resource object or id string of the
     * related resource is returned.<br> In order to obtain information on
     * the resource as well as on the status code of the operation, you
     * must use the callback functions of the deferred object.
     */
    start: function(sync){
    }
});
//</INTERFACE>

dojo.require("com.ibm.mm.enabler.DeferredImpl");
