/* Copyright IBM Corp. 2012  All Rights Reserved.                    */
dojo.provide("com.ibm.mashups.enabler.model.state.NavigationStateModel");

dojo.require("com.ibm.mashups.enabler.Deferred");
//<INTERFACE>
/**
 * Interface for a Navigation state model.<br/>
 * Navigation State API does not garantee that any modifications issued on the API have any further impact on the<br/>
 * user experience of any widgets or components on the page.  Widgets or components may choose to listen to changes on the Navigation</br>
 * State Model and react properly upon those changes. However any user experience change cuased by those components are not part of</br>
 * the contract of this API and therefore these UI behaviour may change going forward<br> 
 * 
 * AccessorFactory API should be used to read/write navigation state within NavigationStateModel.</code><br/>
 * <code>var navStateModel=com.ibm.mashups.enabler.model.state.NavigationStateModelFactory.getNavigationStateModel();</code><br/>
 * <code>var widgetAccessor = com.ibm.mashups.enabler.model.state.AccessorFactory.getWidgetAccessor(navStateModel);</code><br/>
 * <code>widgetAccessor.setSize("200","300");</code><br/>
 * <code>var deferred = navStateModel.commit();</code><br/>
 * <code>deferred.setFinishedCallback(cb);</code><br/>
 * <code>deferred.start();</code><br/> 
 * 
 * @ibm-spi
 * @ibm-module Base
 */
dojo.declare( "com.ibm.mashups.enabler.model.state.NavigationStateModel", null,     {
  
    /**
    * The name of the event to handle to get NavState update notifications.
    * @type String
    */
	ONNAVSTATEUPDATED:"com.ibm.mashups.enabler.model.state.onNavStateUpdated",

    /**
    * This method starts a global transaction for a NavigationStateModel object<br>
    * @type void
    */
    startTransaction: function () {
        return; 
    },
    /**
    * This method commits all changes done withing a global transaction for a NavigationStateModel object<br>
    * @type void
    */
    commitTransaction: function () {
        return; 
    },
    /**
    * This method discards all changes done within a  transaction for a NavigationStateModel object and restores the original NavigationStateModel object.<br>
    * @type void
    */
    discardTransaction: function () {
        return; 
    },
    /**
    * This method starts a global transaction for a NavigationStateModel object<br>
    * @return {boolean} Returns true if a transaction has been started, false otherwise.
	*/
    isTransaction: function () {
        return false; 
    },
  
    /**
    * Commits the modifications applied to this model and all dependent models.<br>
    * @param {Object} additionalParams <i>Optional</i> JSON object to control various aspects while commiting <br> 
    * &nbsp;&nbsp;<b><code>addToHistory</code> (Boolean)</b> - <code>true</code> if the state should be added to the browser history, <code>false</code> otherwise <br>
    * &nbsp;&nbsp;<b><code>allowRedirect</code> (Boolean)</b> - <code>true</code> if the page should be refreshed after the commit, <code>false</code> otherwise.  Note, this parameter is ignored if the commit is synchronous <br>
    * @return {DeferredOperation} a deferred object used to start this operation. 
    * The return value when executed through the deferred object is <code>null</code>
    */
    commit: function (additionalParams) {
        return new com.ibm.mashups.enabler.Deferred(); 
    },

    /**
    * Discards the modifications applied to this model. <br> 
    * @type void
    */
    discard: function () {
        return; 
    },

    /**
    * Dispose this model completely all the navigation state will be destroyed. <br>
    * @type void 
    */
    dispose: function () {
        return; 
    }	
	
});
//</INTERFACE>

dojo.require("com.ibm.mm.enabler.model.state.NavigationStateModelImpl");
